==> phpstan-13431.3718618b1-1-any.pkg.tar.zst: usr/share/doc/phpstan/BACKERS.md <==
# Backers

Development of PHPStan is made possible thanks to these awesome backers!
You can become one of them by [becoming a GitHub Sponsor](https://github.com/sponsors/ondrejmirtes/).

Check out all the tiers - higher ones include additional goodies like placing
the logo of your company in PHPStan's README and the website.

# Gold Company Sponsors

<ul>
<li><a href="https://github.com/check24">CHECK24</a></li>
<!-- gold --><li><a href="https://github.com/m">Matt Mullenweg (m)</a></li>
<!-- gold -->

<!-- gold-org --><li><a href="https://github.com/malsatin">Sergey (malsatin)</a></li>
<!-- gold-org -->
</ul>


# Silver Company Sponsors

<ul>
<li><a href="https://www.startupjobs.cz/startup/shipmonk">Shipmonk</a></li>
<li><a href="https://www.shopware.com/en/">Shopware</a></li>
<!-- silver --><!-- silver -->

<!-- silver-org --><!-- silver-org -->
</ul>

# Bronze Company Sponsors

<ul>
<li><a href="https://packagist.com/">Private Packagist</a></li>
<li><a href="https://www.contentkingapp.com/?ref=php-developer&utm_source=phpstan&utm_medium=referral&utm_campaign=sponsorship">ContentKing</a></li>
<li><a href="https://www.campoint.net">campoint AG</a></li>
<li><a href="https://www.shoptet.cz/">Shoptet</a></li>
<!-- bronze --><li><a href="https://github.com/yositosi"> (yositosi)</a></li>
<li><a href="https://github.com/blackfireio">Blackfire (blackfireio)</a></li>
<li><a href="https://github.com/RightCapitalHQ">RightCapital (RightCapitalHQ)</a></li>
<li><a href="https://github.com/zolweb">ZOL (zolweb)</a></li>
<li><a href="https://github.com/TicketSwap">TicketSwap (TicketSwap)</a></li>
<li><a href="https://github.com/craftcms">Craft CMS (craftcms)</a></li>
<li><a href="https://github.com/cdn77">CDN77.com (cdn77)</a></li>
<!-- bronze -->

<!-- bronze-org --><li><a href="https://github.com/ohgoodlord">Goodlord (ohgoodlord)</a></li>
<li><a href="https://github.com/crispnl">crispnl (crispnl)</a></li>
<li><a href="https://github.com/inviqa">Inviqa (inviqa)</a></li>
<li><a href="https://github.com/hephaist-io">Hephaist.io (hephaist-io)</a></li>
<li><a href="https://github.com/Edgenext2024"> (Edgenext2024)</a></li>
<li><a href="https://github.com/route4me">Route4Me Route Planner (route4me)</a></li>
<li><a href="https://github.com/belsimpel">Belsimpel.nl B.V. (belsimpel)</a></li>
<li><a href="https://github.com/storyblok">Storyblok (storyblok)</a></li>
<li><a href="https://github.com/passbolt">Passbolt (passbolt)</a></li>
<!-- bronze-org -->
</ul>

# Small Teams

<ul>
<!-- small --><li><a href="https://github.com/martin-georgiev">Martin Georgiev (martin-georgiev)</a></li>
<li><a href="https://github.com/glami">GLAMI (glami)</a></li>
<!-- small -->

<!-- small-org --><li><a href="https://github.com/polylang">Polylang (polylang)</a></li>
<li><a href="https://github.com/Enkora">Enkora Oy (Enkora)</a></li>
<li><a href="https://github.com/soster">Stefan Ostermann (soster)</a></li>
<!-- small-org -->
</ul>

# Individual Developers

<ul>
<!-- indi --><li><a href="https://github.com/canvural">Can Vural (canvural)</a></li>
<li><a href="https://github.com/adamlundrigan">Adam Lundrigan (adamlundrigan)</a></li>
<li><a href="https://github.com/escopecz">John Linhart (escopecz)</a></li>
<li><a href="https://github.com/Ocramius">Marco Pivetta (Ocramius)</a></li>
<li><a href="https://github.com/ldebrouwer">Luc (ldebrouwer)</a></li>
<li><a href="https://github.com/Kocal">Hugo Alliaume (Kocal)</a></li>
<li><a href="https://github.com/Dukolm"> (Dukolm)</a></li>
<li><a href="https://github.com/zonuexe">USAMI Kenta (zonuexe)</a></li>
<li><a href="https://github.com/stpnkcrk">Stepan Kocourek (stpnkcrk)</a></li>
<li><a href="https://github.com/NicolasCARPi">Nicolas CARPi (NicolasCARPi)</a></li>
<li><a href="https://github.com/DaveLiddament">Dave Liddament (DaveLiddament)</a></li>
<li><a href="https://github.com/sustmi">Miroslav Šustek (sustmi)</a></li>
<li><a href="https://github.com/ScottHelme">Scott Helme (ScottHelme)</a></li>
<li><a href="https://github.com/forrest79">Jakub Trmota (forrest79)</a></li>
<li><a href="https://github.com/lcobucci">Luís Cobucci (lcobucci)</a></li>
<li><a href="https://github.com/complexgmbh">Complex GmbH & Co. KG (complexgmbh)</a></li>
<li><a href="https://github.com/tenkoma">Koji Tanaka (tenkoma)</a></li>
<li><a href="https://github.com/MidnightDesign">Rudolph Gottesheim (MidnightDesign)</a></li>
<li><a href="https://github.com/vaclavpavek">Václav Pávek (vaclavpavek)</a></li>
<li><a href="https://github.com/einenlum">Yann Rabiller (einenlum)</a></li>
<li><a href="https://github.com/nikophil">Nicolas PHILIPPE (nikophil)</a></li>
<li><a href="https://github.com/solcik">David Šolc (solcik)</a></li>
<li><a href="https://github.com/rieschl">Thomas Rieschl (rieschl)</a></li>
<li><a href="https://github.com/lampbristol">Lamp Bristol (lampbristol)</a></li>
<li><a href="https://github.com/themasch">Mark Schmale (themasch)</a></li>
<li><a href="https://github.com/nicwortel">Nic Wortel (nicwortel)</a></li>
<li><a href="https://github.com/customgento">CustomGento (customgento)</a></li>
<li><a href="https://github.com/johnbillion">John Blackbourn (johnbillion)</a></li>
<li><a href="https://github.com/dbu">David Buchmann (dbu)</a></li>
<li><a href="https://github.com/drealecs">Alexandru Pătrănescu (drealecs)</a></li>
<li><a href="https://github.com/janveselynet">Jan Veselý (janveselynet)</a></li>
<li><a href="https://github.com/Luxian">Lucian NEAG (Luxian)</a></li>
<li><a href="https://github.com/christiansipola">Christian Sjöström (christiansipola)</a></li>
<li><a href="https://github.com/voda">Ondřej Vodáček (voda)</a></li>
<li><a href="https://github.com/brotkrueml">Chris Müller (brotkrueml)</a></li>
<li><a href="https://github.com/joelclermont">Joel Clermont (joelclermont)</a></li>
<li><a href="https://github.com/spaze">Michal Špaček (spaze)</a></li>
<li><a href="https://github.com/kento-oka">Kento Oka (kento-oka)</a></li>
<li><a href="https://github.com/tpetry">Tobias Petry (tpetry)</a></li>
<li><a href="https://github.com/SimoTod">Simone Todaro (SimoTod)</a></li>
<li><a href="https://github.com/rajyan">Yohta Kimura (rajyan)</a></li>
<li><a href="https://github.com/pavlakis">Antonios Pavlakis (pavlakis)</a></li>
<li><a href="https://github.com/p4veI">Pavel Karfík (p4veI)</a></li>
<li><a href="https://github.com/pionl">Martin Kluska (pionl)</a></li>
<li><a href="https://github.com/akondas">Arkadiusz Kondas (akondas)</a></li>
<li><a href="https://github.com/marmichalski">Marcin Michalski (marmichalski)</a></li>
<li><a href="https://github.com/mad-briller">Brad Miller (mad-briller)</a></li>
<li><a href="https://github.com/romm">Romain Canon (romm)</a></li>
<li><a href="https://github.com/RVxLab"> (RVxLab)</a></li>
<li><a href="https://github.com/muno92"> (muno92)</a></li>
<li><a href="https://github.com/underwood">Scott Underwood (underwood)</a></li>
<li><a href="https://github.com/damienalexandre">Damien Alexandre (damienalexandre)</a></li>
<li><a href="https://github.com/driade">David Fernández (driade)</a></li>
<li><a href="https://github.com/ricklambrechts">Rick Lambrechts (ricklambrechts)</a></li>
<li><a href="https://github.com/SomeBdyElse">Hannes Lau (SomeBdyElse)</a></li>
<li><a href="https://github.com/EmilMassey">Emil Masiakowski (EmilMassey)</a></li>
<li><a href="https://github.com/hirokinoue">Hiroki Inoue (hirokinoue)</a></li>
<li><a href="https://github.com/greew">Jesper Skytte Marcussen (greew)</a></li>
<li><a href="https://github.com/jesperbeisner">Jesper Beisner (jesperbeisner)</a></li>
<li><a href="https://github.com/vazaha-nl">Lennart Hengstmengel (vazaha-nl)</a></li>
<li><a href="https://github.com/zbateson">Zaahid Bateson (zbateson)</a></li>
<li><a href="https://github.com/WebBeest">Patrick Kannekens (WebBeest)</a></li>
<li><a href="https://github.com/BernhardK91">Bernhard Krämer (BernhardK91)</a></li>
<li><a href="https://github.com/WyriHaximus">Cees-Jan Kiewiet (WyriHaximus)</a></li>
<li><a href="https://github.com/byWulf">Michael Wolf (byWulf)</a></li>
<li><a href="https://github.com/DrewAPicture">Drew Jaynes (DrewAPicture)</a></li>
<li><a href="https://github.com/amsoell">Andy Soell (amsoell)</a></li>
<li><a href="https://github.com/pauci">Pavol Kirschbaum (pauci)</a></li>
<li><a href="https://github.com/maantje">Jamie Schouten (maantje)</a></li>
<li><a href="https://github.com/Crovitche-1623">Thibault Gattolliat (Crovitche-1623)</a></li>
<li><a href="https://github.com/verfriemelt-dot-org">ಠ_ಠ (verfriemelt-dot-org)</a></li>
<!-- indi -->

<!-- indi-org --><li><a href="https://github.com/hxv">Michał Włodarczyk (hxv)</a></li>
<li><a href="https://github.com/midatechsro">midatechsro (midatechsro)</a></li>
<li><a href="https://github.com/Schrank">Fabian Blechschmidt (Schrank)</a></li>
<li><a href="https://github.com/ScottHelme">Scott Helme (ScottHelme)</a></li>
<li><a href="https://github.com/aspirantzhang">Aspirant Zhang (aspirantzhang)</a></li>
<li><a href="https://github.com/oliverklee">Oliver Klee (oliverklee)</a></li>
<li><a href="https://github.com/encore-mieux">Encore Mieux (encore-mieux)</a></li>
<li><a href="https://github.com/acelaya">Alejandro Celaya (acelaya)</a></li>
<li><a href="https://github.com/eliashaeussler">Elias Häußler (eliashaeussler)</a></li>
<li><a href="https://github.com/tomasnorre">Tomas Norre Mikkelsen (tomasnorre)</a></li>
<li><a href="https://github.com/lucassabreu">Lucas dos Santos Abreu (lucassabreu)</a></li>
<li><a href="https://github.com/westonruter">Weston Ruter (westonruter)</a></li>
<li><a href="https://github.com/mceglowski"> (mceglowski)</a></li>
<li><a href="https://github.com/olliescase">Oliver Scase (olliescase)</a></li>
<li><a href="https://github.com/zajca">Martin Zajíc (zajca)</a></li>
<li><a href="https://github.com/tenkoma">Koji Tanaka (tenkoma)</a></li>
<li><a href="https://github.com/stafftastic">stafftastic GmbH (stafftastic)</a></li>
<li><a href="https://github.com/AllenJB">AllenJB (AllenJB)</a></li>
<li><a href="https://github.com/stopfstedt">Stefan Topfstedt (stopfstedt)</a></li>
<li><a href="https://github.com/kingkero">Martin Rehberger (kingkero)</a></li>
<li><a href="https://github.com/previousnext">PreviousNext (previousnext)</a></li>
<li><a href="https://github.com/erik-perri">Erik Perri (erik-perri)</a></li>
<li><a href="https://github.com/alisqi">AlisQI (alisqi)</a></li>
<li><a href="https://github.com/WyriHaximus">Cees-Jan Kiewiet (WyriHaximus)</a></li>
<li><a href="https://github.com/lubatti">Lautaro Lubatti (lubatti)</a></li>
<li><a href="https://github.com/kassner">Rafael Kassner (kassner)</a></li>
<li><a href="https://github.com/ssddanbrown">Dan Brown (ssddanbrown)</a></li>
<li><a href="https://github.com/epic-64">William Raendchen (epic-64)</a></li>
<li><a href="https://github.com/M-arcus">Marcus Müller (M-arcus)</a></li>
<li><a href="https://github.com/BinaryKitten">Kathryn Reeve (BinaryKitten)</a></li>
<li><a href="https://github.com/richardgaunt"> (richardgaunt)</a></li>
<li><a href="https://github.com/pxlrbt">Dennis Koch (pxlrbt)</a></li>
<li><a href="https://github.com/fetova"> (fetova)</a></li>
<li><a href="https://github.com/m1rm">Miriam Müller (m1rm)</a></li>
<!-- indi-org -->
</ul>

==> phpstan-13729.451b54250-1-any.pkg.tar.zst: usr/share/doc/phpstan/BACKERS.md <==
# Backers

Development of PHPStan is made possible thanks to these awesome backers!
You can become one of them by [becoming a GitHub Sponsor](https://github.com/sponsors/ondrejmirtes/).

Check out all the tiers - higher ones include additional goodies like placing
the logo of your company in PHPStan's README and the website.

# Gold Company Sponsors

<ul>
<li><a href="https://github.com/check24">CHECK24</a></li>
<!-- gold --><li><a href="https://github.com/m">Matt Mullenweg (m)</a></li>
<!-- gold -->

<!-- gold-org --><li><a href="https://github.com/malsatin">Sergey (malsatin)</a></li>
<!-- gold-org -->
</ul>


# Silver Company Sponsors

<ul>
<li><a href="https://www.startupjobs.cz/startup/shipmonk">Shipmonk</a></li>
<li><a href="https://www.shopware.com/en/">Shopware</a></li>
<!-- silver --><!-- silver -->

<!-- silver-org --><!-- silver-org -->
</ul>

# Bronze Company Sponsors

<ul>
<li><a href="https://packagist.com/">Private Packagist</a></li>
<li><a href="https://www.contentkingapp.com/?ref=php-developer&utm_source=phpstan&utm_medium=referral&utm_campaign=sponsorship">ContentKing</a></li>
<li><a href="https://www.campoint.net">campoint AG</a></li>
<li><a href="https://www.shoptet.cz/">Shoptet</a></li>
<!-- bronze --><li><a href="https://github.com/yositosi"> (yositosi)</a></li>
<li><a href="https://github.com/blackfireio">Blackfire (blackfireio)</a></li>
<li><a href="https://github.com/RightCapitalHQ">RightCapital (RightCapitalHQ)</a></li>
<li><a href="https://github.com/zolweb">ZOL (zolweb)</a></li>
<li><a href="https://github.com/TicketSwap">TicketSwap (TicketSwap)</a></li>
<li><a href="https://github.com/craftcms">Craft CMS (craftcms)</a></li>
<li><a href="https://github.com/cdn77">CDN77.com (cdn77)</a></li>
<!-- bronze -->

<!-- bronze-org --><li><a href="https://github.com/ohgoodlord">Goodlord (ohgoodlord)</a></li>
<li><a href="https://github.com/crispnl">crispnl (crispnl)</a></li>
<li><a href="https://github.com/inviqa">Inviqa (inviqa)</a></li>
<li><a href="https://github.com/hephaist-io">Hephaist.io (hephaist-io)</a></li>
<li><a href="https://github.com/Edgenext2024"> (Edgenext2024)</a></li>
<li><a href="https://github.com/FameHelsinki">Fame Helsinki (FameHelsinki)</a></li>
<li><a href="https://github.com/route4me">Route4Me Route Planner (route4me)</a></li>
<li><a href="https://github.com/belsimpel">Belsimpel.nl B.V. (belsimpel)</a></li>
<li><a href="https://github.com/storyblok">Storyblok (storyblok)</a></li>
<li><a href="https://github.com/passbolt">Passbolt (passbolt)</a></li>
<!-- bronze-org -->
</ul>

# Small Teams

<ul>
<!-- small --><li><a href="https://github.com/martin-georgiev">Martin Georgiev (martin-georgiev)</a></li>
<li><a href="https://github.com/glami">GLAMI (glami)</a></li>
<!-- small -->

<!-- small-org --><li><a href="https://github.com/polylang">Polylang (polylang)</a></li>
<li><a href="https://github.com/Enkora">Enkora Oy (Enkora)</a></li>
<!-- small-org -->
</ul>

# Individual Developers

<ul>
<!-- indi --><li><a href="https://github.com/canvural">Can Vural (canvural)</a></li>
<li><a href="https://github.com/adamlundrigan">Adam Lundrigan (adamlundrigan)</a></li>
<li><a href="https://github.com/escopecz">John Linhart (escopecz)</a></li>
<li><a href="https://github.com/Ocramius">Marco Pivetta (Ocramius)</a></li>
<li><a href="https://github.com/ldebrouwer">Luc (ldebrouwer)</a></li>
<li><a href="https://github.com/Kocal">Hugo Alliaume (Kocal)</a></li>
<li><a href="https://github.com/Dukolm"> (Dukolm)</a></li>
<li><a href="https://github.com/zonuexe">USAMI Kenta (zonuexe)</a></li>
<li><a href="https://github.com/stpnkcrk">Stepan Kocourek (stpnkcrk)</a></li>
<li><a href="https://github.com/NicolasCARPi">Nicolas CARPi (NicolasCARPi)</a></li>
<li><a href="https://github.com/DaveLiddament">Dave Liddament (DaveLiddament)</a></li>
<li><a href="https://github.com/sustmi">Miroslav Šustek (sustmi)</a></li>
<li><a href="https://github.com/ScottHelme">Scott Helme (ScottHelme)</a></li>
<li><a href="https://github.com/forrest79">Jakub Trmota (forrest79)</a></li>
<li><a href="https://github.com/lcobucci">Luís Cobucci (lcobucci)</a></li>
<li><a href="https://github.com/complexgmbh">Complex GmbH & Co. KG (complexgmbh)</a></li>
<li><a href="https://github.com/tenkoma">Koji Tanaka (tenkoma)</a></li>
<li><a href="https://github.com/MidnightDesign">Rudolph Gottesheim (MidnightDesign)</a></li>
<li><a href="https://github.com/vaclavpavek">Václav Pávek (vaclavpavek)</a></li>
<li><a href="https://github.com/afilina">Anna Filina (afilina)</a></li>
<li><a href="https://github.com/einenlum">Yann Rabiller (einenlum)</a></li>
<li><a href="https://github.com/nikophil">Nicolas PHILIPPE (nikophil)</a></li>
<li><a href="https://github.com/solcik">David Šolc (solcik)</a></li>
<li><a href="https://github.com/rieschl">Thomas Rieschl (rieschl)</a></li>
<li><a href="https://github.com/lampbristol">Lamp Bristol (lampbristol)</a></li>
<li><a href="https://github.com/themasch">Mark Schmale (themasch)</a></li>
<li><a href="https://github.com/nicwortel">Nic Wortel (nicwortel)</a></li>
<li><a href="https://github.com/customgento">CustomGento (customgento)</a></li>
<li><a href="https://github.com/johnbillion">John Blackbourn (johnbillion)</a></li>
<li><a href="https://github.com/dbu">David Buchmann (dbu)</a></li>
<li><a href="https://github.com/drealecs">Alexandru Pătrănescu (drealecs)</a></li>
<li><a href="https://github.com/janveselynet">Jan Veselý (janveselynet)</a></li>
<li><a href="https://github.com/Luxian">Lucian NEAG (Luxian)</a></li>
<li><a href="https://github.com/christiansipola">Christian Sjöström (christiansipola)</a></li>
<li><a href="https://github.com/voda">Ondřej Vodáček (voda)</a></li>
<li><a href="https://github.com/brotkrueml">Chris Müller (brotkrueml)</a></li>
<li><a href="https://github.com/joelclermont">Joel Clermont (joelclermont)</a></li>
<li><a href="https://github.com/spaze">Michal Špaček (spaze)</a></li>
<li><a href="https://github.com/kento-oka">Kento Oka (kento-oka)</a></li>
<li><a href="https://github.com/tpetry">Tobias Petry (tpetry)</a></li>
<li><a href="https://github.com/SimoTod">Simone Todaro (SimoTod)</a></li>
<li><a href="https://github.com/rajyan">Yohta Kimura (rajyan)</a></li>
<li><a href="https://github.com/pavlakis">Antonios Pavlakis (pavlakis)</a></li>
<li><a href="https://github.com/p4veI">Pavel Karfík (p4veI)</a></li>
<li><a href="https://github.com/pionl">Martin Kluska (pionl)</a></li>
<li><a href="https://github.com/akondas">Arkadiusz Kondas (akondas)</a></li>
<li><a href="https://github.com/marmichalski">Marcin Michalski (marmichalski)</a></li>
<li><a href="https://github.com/mad-briller">Brad Miller (mad-briller)</a></li>
<li><a href="https://github.com/romm">Romain Canon (romm)</a></li>
<li><a href="https://github.com/RVxLab"> (RVxLab)</a></li>
<li><a href="https://github.com/muno92"> (muno92)</a></li>
<li><a href="https://github.com/damienalexandre">Damien Alexandre (damienalexandre)</a></li>
<li><a href="https://github.com/driade">David Fernández (driade)</a></li>
<li><a href="https://github.com/ricklambrechts">Rick Lambrechts (ricklambrechts)</a></li>
<li><a href="https://github.com/SomeBdyElse">Hannes Lau (SomeBdyElse)</a></li>
<li><a href="https://github.com/EmilMassey">Emil Masiakowski (EmilMassey)</a></li>
<li><a href="https://github.com/hirokinoue">Hiroki Inoue (hirokinoue)</a></li>
<li><a href="https://github.com/greew">Jesper Skytte Marcussen (greew)</a></li>
<li><a href="https://github.com/jesperbeisner">Jesper Beisner (jesperbeisner)</a></li>
<li><a href="https://github.com/vazaha-nl">Lennart Hengstmengel (vazaha-nl)</a></li>
<li><a href="https://github.com/zbateson">Zaahid Bateson (zbateson)</a></li>
<li><a href="https://github.com/WebBeest">Patrick Kannekens (WebBeest)</a></li>
<li><a href="https://github.com/BernhardK91">Bernhard Krämer (BernhardK91)</a></li>
<li><a href="https://github.com/WyriHaximus">Cees-Jan Kiewiet (WyriHaximus)</a></li>
<li><a href="https://github.com/byWulf">Michael Wolf (byWulf)</a></li>
<li><a href="https://github.com/DrewAPicture">Drew Jaynes (DrewAPicture)</a></li>
<li><a href="https://github.com/amsoell">Andy Soell (amsoell)</a></li>
<li><a href="https://github.com/pauci">Pavol Kirschbaum (pauci)</a></li>
<li><a href="https://github.com/maantje">Jamie Schouten (maantje)</a></li>
<li><a href="https://github.com/verfriemelt-dot-org">ಠ_ಠ (verfriemelt-dot-org)</a></li>
<!-- indi -->

<!-- indi-org --><li><a href="https://github.com/hxv">Michał Włodarczyk (hxv)</a></li>
<li><a href="https://github.com/midatechsro">midatechsro (midatechsro)</a></li>
<li><a href="https://github.com/Schrank">Fabian Blechschmidt (Schrank)</a></li>
<li><a href="https://github.com/ScottHelme">Scott Helme (ScottHelme)</a></li>
<li><a href="https://github.com/aspirantzhang">Aspirant Zhang (aspirantzhang)</a></li>
<li><a href="https://github.com/oliverklee">Oliver Klee (oliverklee)</a></li>
<li><a href="https://github.com/encore-mieux">Encore Mieux (encore-mieux)</a></li>
<li><a href="https://github.com/acelaya">Alejandro Celaya (acelaya)</a></li>
<li><a href="https://github.com/eliashaeussler">Elias Häußler (eliashaeussler)</a></li>
<li><a href="https://github.com/lucassabreu">Lucas dos Santos Abreu (lucassabreu)</a></li>
<li><a href="https://github.com/westonruter">Weston Ruter (westonruter)</a></li>
<li><a href="https://github.com/mceglowski"> (mceglowski)</a></li>
<li><a href="https://github.com/zajca">Martin Zajíc (zajca)</a></li>
<li><a href="https://github.com/tenkoma">Koji Tanaka (tenkoma)</a></li>
<li><a href="https://github.com/stafftastic">stafftastic GmbH (stafftastic)</a></li>
<li><a href="https://github.com/AllenJB">AllenJB (AllenJB)</a></li>
<li><a href="https://github.com/stopfstedt">Stefan Topfstedt (stopfstedt)</a></li>
<li><a href="https://github.com/kingkero">Martin Rehberger (kingkero)</a></li>
<li><a href="https://github.com/previousnext">PreviousNext (previousnext)</a></li>
<li><a href="https://github.com/erik-perri">Erik Perri (erik-perri)</a></li>
<li><a href="https://github.com/alisqi">AlisQI (alisqi)</a></li>
<li><a href="https://github.com/WyriHaximus">Cees-Jan Kiewiet (WyriHaximus)</a></li>
<li><a href="https://github.com/lubatti">Lautaro Lubatti (lubatti)</a></li>
<li><a href="https://github.com/kassner">Rafael Kassner (kassner)</a></li>
<li><a href="https://github.com/ssddanbrown">Dan Brown (ssddanbrown)</a></li>
<li><a href="https://github.com/epic-64">William Raendchen (epic-64)</a></li>
<li><a href="https://github.com/M-arcus">Marcus Müller (M-arcus)</a></li>
<li><a href="https://github.com/BinaryKitten">Kathryn Reeve (BinaryKitten)</a></li>
<li><a href="https://github.com/richardgaunt"> (richardgaunt)</a></li>
<li><a href="https://github.com/pxlrbt">Dennis Koch (pxlrbt)</a></li>
<li><a href="https://github.com/fetova"> (fetova)</a></li>
<li><a href="https://github.com/m1rm">Miriam Müller (m1rm)</a></li>
<li><a href="https://github.com/matijabelec">Matija (matijabelec)</a></li>
<!-- indi-org -->
</ul>
